/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * This attribute controller can be used by active components that need
 * registering one or more tasks. It must be used by components using the
 * {@link org.objectweb.dream.control.activity.task.ThreadPerTaskTaskManagerControllerMixin}
 * activity manager. It allows defining whether tasks have to be executed by a
 * thread pool or only by a thread. Moreover, in cases the thread pool has been
 * chosen, it allows setting the initial number of threads, as well as the max
 * capacity of the pool.
 * 
 * @see org.objectweb.dream.control.activity.task.thread.ThreadPoolController
 */
public interface ActiveComponentAttributeController extends AttributeController
{
  /**
   * Determines whether a pool of threads should be used for each task of the
   * component.
   * 
   * @param usePool the value to set.
   */
  void setUsePool(boolean usePool);

  /**
   * Indicates whether a pool of threads is used for each task of the component.
   * 
   * @return <code>true</code> if task is executed by a pool of thread.
   */
  boolean getUsePool();

  /**
   * Sets the initial capacity of the pool.
   * 
   * @param i the initial capacity of the pool.
   */
  void setInitialCapacity(int i);

  /**
   * Returns the maximum capacity of the pool.
   * 
   * @return the maximum capacity of the pool.
   */
  int getInitialCapacity();

  /**
   * Sets the initial number of threads in the pool.
   * 
   * @param i the initial number of threads in the pool.
   */
  void setInitialNumberOfThreads(int i);

  /**
   * Returns the initial number of threads in the pool.
   * 
   * @return the initial number of threads in the pool.
   */
  int getInitialNumberOfThreads();

}