/**
 * Dream Copyright (C) 2003-2004 INRIA Rhone-Alpes
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any
 * later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * Contact: dream@objectweb.org
 * 
 * Initial developer(s): Matthieu Leclercq 
 * Contributor(s):
 */

package org.objectweb.dream.control.activity.task;

import org.objectweb.dream.util.Error;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Mixin that delegate method to content object. The content of the component
 * must implements {@link TaskLifeCycleController}.
 */
public abstract class ContainerLifeCycleMixin
    implements
      TaskLifeCycleController
{

  // -------------------------------------------------------------------------
  // Private constructor
  // -------------------------------------------------------------------------

  private ContainerLifeCycleMixin()
  {
  }

  // -------------------------------------------------------------------------
  // Fields and methods added and overriden by the mixin class
  // -------------------------------------------------------------------------

  /**
   * @see TaskLifeCycleController#asyncStop(TaskStoppedListener)
   */
  public void asyncStop(TaskStoppedListener listener)
  {
    getContent().asyncStop(listener);
  }

  /**
   * @see org.objectweb.fractal.api.control.LifeCycleController#getFcState()
   */
  public String getFcState()
  {
    return getContent().getFcState();
  }

  /**
   * @see org.objectweb.fractal.api.control.LifeCycleController#startFc()
   */
  public void startFc() throws IllegalLifeCycleException
  {
    getContent().startFc();
  }

  /**
   * @see org.objectweb.fractal.api.control.LifeCycleController#stopFc()
   */
  public void stopFc() throws IllegalLifeCycleException
  {
    getContent().stopFc();
  }

  /**
   * Returns the content of the component.
   * 
   * @return the content of the component.
   */
  public TaskLifeCycleController getContent()
  {
    try
    {
      return (TaskLifeCycleController) _this_weaveableOptC
          .getFcInterface("/content");
    }
    catch (NoSuchInterfaceException e)
    {
      Error.error("Unable to find component content", null);
      return null;
    }
    catch (ClassCastException e)
    {
      Error.error(
          "The content object does not implements TaskLifeCycleController",
          null);
      return null;
    }
  }

  // -------------------------------------------------------------------------
  // Fields and methods required by the mixin class in the base class
  // -------------------------------------------------------------------------

  /**
   * The <tt>weaveableOptC</tt> field required by this mixin. This field is
   * supposed to reference the {@link Component}interface of the component to
   * which this controller object belongs.
   */

  public Component _this_weaveableOptC;

}