/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.pool;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * An attribute controller for object pools.
 */
public interface ObjectPoolAttributeController extends AttributeController
{

  /**
   * Returns the object pool capacity.
   * 
   * @return the object pool capacity.
   */
  int getCapacity();

  /**
   * Sets the object pool capacity.
   * 
   * @param capacity the object pool capacity.
   */
  void setCapacity(int capacity);

  /**
   * Returns the class name of objects that are managed by the pool to which
   * this interface belongs.
   * 
   * @return the class name of managed objects.
   */
  String getObjectClassName();

  /**
   * Sets the class name of objects that are managed by the pool to which this
   * interface belongs.
   * 
   * @param name the class name of managed objects.
   */
  void setObjectClassName(String name);

}